@@ -23,15 +23,16 @@ class Block(object):
         it: [],
     }
 
-    def __init__(self, indent, name, words, rest=None):
+    def __init__(self, indent, name, words, lineno, rest=None):
         self.indent = len(indent)
         self.name = name
         self.words = words
+        self.lineno = lineno
         self.code = []
         if rest:
             if self.name == self.let and not rest.startswith('return'):
                 rest = "return (%s)" % rest
-            self.code.append(rest)
+            self.code.append((lineno, rest))
         if self.name in [self.before, self.after]:
             self.words += utils.uuid_hex()
 
